==> vunit_hdl-4.5.0.tar.gz: vunit_hdl-4.5.0/README.md <==
<p align="center">
  <a title="vunit.github.io"
     href="http://vunit.github.io"
  ><img src="https://img.shields.io/website.svg?label=vunit.github.io&longCache=true&style=flat-square&url=http%3A%2F%2Fvunit.github.io%2Findex.html"
  /></a><!--
  -->
  <a title="Join the chat at https://gitter.im/VUnit/vunit"
     href="https://gitter.im/VUnit/vunit"
  ><img src="https://img.shields.io/gitter/room/VUnit/vunit.svg?longCache=true&style=flat-square&logo=gitter&logoColor=4db797&color=4db797"
  /></a><!--
  -->
  <a title="@VUnitFramework"
     href="https://www.twitter.com/VUnitFramework"
  ><img src="https://img.shields.io/twitter/follow/VUnitFramework.svg?longCache=true&style=flat-square&color=1DA1F2&label=%40VUnitFramework&logo=twitter&logoColor=fff"
  /></a>
</p>

<p align="center">
  <a title="PyPI vunit_hdl"
     href="https://pypi.org/project/vunit-hdl/"
  ><img src="https://img.shields.io/pypi/v/vunit_hdl?longCache=true&style=flat-square&label=PyPI&logo=PyPI&logoColor=FFF"
  /></a><!--
  -->
  <a title="Commits since latest release"
     href="https://github.com/VUnit/vunit/releases"
  ><img src="https://img.shields.io/github/commits-since/VUnit/vunit/latest.svg?longCache=true&style=flat-square&logo=git&logoColor=fff"
  /></a><!--
  -->
  <a title="'docs' workflow Status"
     href="https://github.com/VUnit/vunit/actions?query=workflow%3Adocs"
  ><img alt="'docs' workflow Status" src="https://img.shields.io/github/workflow/status/VUnit/vunit/docs?longCache=true&style=flat-square&label=docs"
  /></a><!--
  -->
  <a title="'images' workflow Status"
     href="https://github.com/VUnit/vunit/actions?query=workflow%3Aimages"
  ><img alt="'images' workflow Status" src="https://img.shields.io/github/workflow/status/VUnit/vunit/images?longCache=true&style=flat-square&label=imgs"
  /></a><!--
  -->
  <a title="'push' workflow Status"
     href="https://github.com/VUnit/vunit/actions?query=workflow%3Apush"
  ><img alt="'push' workflow Status" src="https://img.shields.io/github/workflow/status/VUnit/vunit/push?longCache=true&style=flat-square&label=push"
  /></a><!--
  -->
  <a title="'coverage' workflow Status"
     href="https://github.com/VUnit/vunit/actions?query=workflow%3Acoverage"
  ><img alt="'coverage' workflow Status" src="https://img.shields.io/github/workflow/status/VUnit/vunit/coverage?longCache=true&style=flat-square&label=coverage"
  /></a>
</p>

**VUnit** is an [open source](LICENSE.rst) unit testing framework for VHDL/SystemVerilog. It features the functionality
needed to realize continuous and automated testing of your HDL code. VUnit doesn't replace but rather complements
traditional testing methodologies by supporting a *test early and often* approach through automation.
**Read more** [about VUnit](http://vunit.github.io/about.html).

Contributing in the form of code, docs, feedback, ideas or bug reports is welcome.
Read our [contribution guide](https://vunit.github.io/contributing.html) to get started.

<p align="center">
  <a href="http://vunit.github.io"><img width="550px" src="docs/_static/vunit_demo.gif"/></a>
</p>

==> vunit_hdl-4.6.1.tar.gz: vunit_hdl-4.6.1/README.md <==
<p align="center">
  <a title="vunit.github.io"
     href="http://vunit.github.io"
  ><img src="https://img.shields.io/website.svg?label=vunit.github.io&longCache=true&style=flat-square&url=http%3A%2F%2Fvunit.github.io%2Findex.html"
  /></a><!--
  -->
  <a title="Join the chat at https://gitter.im/VUnit/vunit"
     href="https://gitter.im/VUnit/vunit"
  ><img src="https://img.shields.io/gitter/room/VUnit/vunit.svg?longCache=true&style=flat-square&logo=gitter&logoColor=4db797&color=4db797"
  /></a><!--
  -->
  <a title="@VUnitFramework"
     href="https://www.twitter.com/VUnitFramework"
  ><img src="https://img.shields.io/twitter/follow/VUnitFramework.svg?longCache=true&style=flat-square&color=1DA1F2&label=%40VUnitFramework&logo=twitter&logoColor=fff"
  /></a>
</p>

<p align="center">
  <a title="PyPI vunit_hdl"
     href="https://pypi.org/project/vunit-hdl/"
  ><img src="https://img.shields.io/pypi/v/vunit_hdl?longCache=true&style=flat-square&label=PyPI&logo=PyPI&logoColor=FFF"
  /></a><!--
  -->
  <a title="Commits since latest release"
     href="https://github.com/VUnit/vunit/releases"
  ><img src="https://img.shields.io/github/commits-since/VUnit/vunit/latest.svg?longCache=true&style=flat-square&logo=git&logoColor=fff"
  /></a><!--
  -->
  <a title="'docs' workflow Status"
     href="https://github.com/VUnit/vunit/actions?query=workflow%3Adocs"
  ><img alt="'docs' workflow Status" src="https://img.shields.io/github/workflow/status/VUnit/vunit/docs/master?longCache=true&style=flat-square&label=docs"
  /></a><!--
  -->
  <a title="'images' workflow Status"
     href="https://github.com/VUnit/vunit/actions?query=workflow%3Aimages"
  ><img alt="'images' workflow Status" src="https://img.shields.io/github/workflow/status/VUnit/vunit/images/master?longCache=true&style=flat-square&label=imgs"
  /></a><!--
  -->
  <a title="'push' workflow Status"
     href="https://github.com/VUnit/vunit/actions?query=workflow%3Apush"
  ><img alt="'push' workflow Status" src="https://img.shields.io/github/workflow/status/VUnit/vunit/push/master?longCache=true&style=flat-square&label=push"
  /></a><!--
  -->
  <a title="'coverage' workflow Status"
     href="https://github.com/VUnit/vunit/actions?query=workflow%3Acoverage"
  ><img alt="'coverage' workflow Status" src="https://img.shields.io/github/workflow/status/VUnit/vunit/coverage/master?longCache=true&style=flat-square&label=coverage"
  /></a>
</p>

**VUnit** is an [open source](LICENSE.rst) unit testing framework for VHDL/SystemVerilog. It features the functionality
needed to realize continuous and automated testing of your HDL code. VUnit doesn't replace but rather complements
traditional testing methodologies by supporting a *test early and often* approach through automation.
**Read more** [about VUnit](http://vunit.github.io/about.html).

Contributing in the form of code, docs, feedback, ideas or bug reports is welcome.
Read our [contribution guide](https://vunit.github.io/contributing.html) to get started.

<p align="center">
  <a href="http://vunit.github.io"><img width="550px" src="docs/_static/vunit_demo.gif"/></a>
</p>
